@@ -18,7 +18,7 @@ function RUN_TOOL()
 ###############################################################################
 #
 #
-PKG_NAME="kvirc"
+PKG_NAME="kvirc2"
 DIE=0
 GEN_FILES="configure.ac"
 ACLOCAL_FLAGS="-I m4"
@@ -105,11 +105,11 @@ do
 			cat $MACRO_FILES > acinclude.m4
 
 			RUN_TOOL libtoolize --copy --force
-			RUN_TOOL aclocal $aclocalinclude
+			RUN_TOOL aclocal-1.9 $aclocalinclude
 			if grep "^AM_CONFIG_HEADER" $coin > /dev/null; then
 				RUN_TOOL autoheader
 			fi
-			RUN_TOOL automake --add-missing --copy $am_opt
+			RUN_TOOL automake-1.9 --add-missing --copy $am_opt
 			RUN_TOOL autoconf
 			touch stamp-h.in
 		)
