@@ -35,14 +35,10 @@
 
 #include "kvi_settings.h"
 
-//
-//  Sigh...
-//  IRC is not Unicode...(yet) :(
-//
 #ifdef COMPILE_USE_LOCAL_8BIT_ENCODING
 	#define _CHAR_2_QSTRING(__chptr) QString::fromLocal8Bit(__chptr)
 #else
-	#define _CHAR_2_QSTRING(__chptr) QString(__chptr)
+	#define _CHAR_2_QSTRING(__chptr) QString::fromUtf8(__chptr)
 #endif
 
 #undef __kvi_extern
