@@ -23,6 +23,12 @@
 
 #include "kvi_accel_kde.h"
 
+KviAccel::KviAccel(QWidget *watch, QObject *parent, const char *psName)
+	: KAccel(watch, parent, psName)
+{
+	// Nothing here
+}
+
 KviAccel::KviAccel(QWidget *parent, const char *name)
 	: KAccel(parent, name)
 {
