@@ -30,7 +30,7 @@ class KviApplication : public KApplication
 {
 	Q_OBJECT
 public:
-	KviApplication(int argc, char **argv, const char *appname);
+	KviApplication(int argc, char **argv, const char *appName);
 	~KviApplication();
 };
 
