@@ -24,14 +24,17 @@
 //
 // =============================================================================
 
-#include <klineeditdlg.h>
+class QString;
+class QWidget;
 
-class KviLineEditDialog : public KLineEditDlg
+class KviLineEditDialog
 {
-	Q_OBJECT
+private:
+	KviLineEditDialog();
 public:
-	KviLineEditDialog(const QString &text, const QString &value, QWidget *parent);
 	~KviLineEditDialog();
+
+	static QString getText(const QString &caption, const QString &text, const QString &value, bool *ok, QWidget *parent);
 };
 
 #endif // _KVI_LINEEDITDIALOG_KDE_H_INCLUDED_
