@@ -1,11 +1,11 @@
 #ifndef _KVI_JPEGIO_H_INCLUDED_
 #define _KVI_JPEGIO_H_INCLUDED_
 
+// =============================================================================
 //
-//   File : kvi_jpegio.h (/usr/build/NEW_kvirc/kvirc/src/kvilib/kvi_jpegio.h)
-//   Last major modification : Sun May 9 1999 05:19:42 by Szymon Stefanek
+//      --- kvi_jpegio.h ---
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc IRC client distribution
 //   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -20,9 +20,10 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program. If not, write to the Free Software Foundation,
-//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+// =============================================================================
 
 extern void kvi_initJpegIo();
 
-#endif //!_KVI_JPEGIO_H_INCLUDED_
+#endif // _KVI_JPEGIO_H_INCLUDED_
