@@ -67,15 +67,15 @@ KviMdiChild::KviMdiChild(KviMdiManager *parent, const char *name)
 
 	m_pMinimize = new KviMdiButton(m_pCaption, KviMdiButton::Minimize, "minimize_button");
 	connect(m_pMinimize, SIGNAL(buttonPressed()), this, SLOT(minimizePressed()));
-	QToolTip::add(m_pMinimize, _CHAR_2_QSTRING(__tr("Minimize")));
+	QToolTip::add(m_pMinimize, _CHAR_2_QSTRING(_i18n_("Minimize")));
 
 	m_pMaximize = new KviMdiButton(m_pCaption, KviMdiButton::Maximize, "maximize_button");
 	connect(m_pMaximize, SIGNAL(buttonPressed()), this, SLOT(maximizePressed()));
-	QToolTip::add(m_pMaximize, _CHAR_2_QSTRING(__tr("Maximize")));
+	QToolTip::add(m_pMaximize, _CHAR_2_QSTRING(_i18n_("Maximize")));
 
 	m_pClose    = new KviMdiButton(m_pCaption, KviMdiButton::Close, "close_button");
 	connect(m_pClose, SIGNAL(buttonPressed()), this, SLOT(closePressed()));
-	QToolTip::add(m_pClose, _CHAR_2_QSTRING(__tr("Close")));
+	QToolTip::add(m_pClose, _CHAR_2_QSTRING(_i18n_("Close")));
 
 	setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 	setFocusPolicy(ClickFocus);
@@ -514,7 +514,7 @@ void KviMdiChild::setCaption(const char *text)
 
 const char *KviMdiChild::caption()
 {
-	return m_pCaption->m_szCaption.ptr();
+	return m_pCaption->m_szCaption;
 }
 
 // ============ enableClose ==============
