@@ -23,6 +23,12 @@
 
 #include "kvi_accel_qt.h"
 
+KviAccel::KviAccel(QWidget *watch, QObject *parent, const char *psName)
+	: QAccel(watch, parent, psName)
+{
+	// Nothing here
+}
+
 KviAccel::KviAccel(QWidget *parent, const char *name)
 	: QAccel(parent, name)
 {
@@ -34,4 +40,9 @@ KviAccel::~KviAccel()
 	// Nothing here
 }
 
+const QKeySequence KviAccel::shortcut(const QString &action) const
+{
+	return QAccel::stringToKey(action);
+}
+
 #include "m_kvi_accel_qt.moc"
