@@ -138,7 +138,7 @@ void KviDccVoiceThread::eventLoop()
 						close(m_pData->soundFd);
 					m_pData->soundFd = -1;
 					m_pData->tmpBuffer.sprintf(
-						__tr("WARNING: cannot open sound card for reading (%s)"),
+						_i18n_("WARNING: cannot open sound card for reading (%s)"),
 						kvi_getErrorString(iError)
 					);
 					KviDccEvent *ev = new KviDccEvent(KVI_DCC_EVENT_MSG, m_pData->tmpBuffer.ptr());
@@ -205,7 +205,7 @@ bool KviDccVoiceThread::sendSample()
 		int wrote = write(m_socket, (void *) ((s->buffer) + m_pData->lastSentSize), toSend);
 
 		if( wrote < 0 ) {
-			abort(__tr("Error while writing to the socket: connection lost"), m_pData->parent);
+			abort(_i18n_("Error while writing to the socket: connection lost"), m_pData->parent);
 			return false;
 		} else {
 			if( wrote == toSend ) {
@@ -239,7 +239,7 @@ bool KviDccVoiceThread::receiveData()
 	if( bRead <= 0 ) {
 		// Oops?
 		if( bRead == 0 ) {
-			abort(__tr("Remote end has closed the connection"), m_pData->parent);
+			abort(_i18n_("Remote end has closed the connection"), m_pData->parent);
 			return false;
 		} else { // Error?
 			if( (errno == EINTR) || (errno == EAGAIN) )
@@ -256,7 +256,7 @@ bool KviDccVoiceThread::receiveData()
 				default:           iError = -errno;                          break;
 			}
 			// Post the error event to the parent and exit
-			m_pData->tmpBuffer.sprintf(__tr("READ ERROR: %s"), kvi_getErrorString(iError));
+			m_pData->tmpBuffer.sprintf(_i18n_("READ ERROR: %s"), kvi_getErrorString(iError));
 			abort(m_pData->tmpBuffer.ptr(), m_pData->parent);
 			return false;
 		}
@@ -287,7 +287,7 @@ bool KviDccVoiceThread::receiveData()
 			}
 			m_pData->recvQueueCount++;
 
-			m_pData->tmpBuffer.sprintf(__tr("Buffered: %d milliseconds"), m_pData->recvQueueCount * 128);
+			m_pData->tmpBuffer.sprintf(_i18n_("Buffered: %d milliseconds"), m_pData->recvQueueCount * 128);
 			KviDccEvent *ev = new KviDccEvent(KVI_DCC_EVENT_BUFFEREDTIME, m_pData->tmpBuffer.ptr());
 			KviApplication::postEvent(m_pData->parent, ev);
 
@@ -327,7 +327,7 @@ void KviDccVoiceThread::playbackLoop()
 		if( m_pData->soundFd != -1 )
 			close(m_pData->soundFd);
 		m_pData->soundFd = -1;
-		m_pData->tmpBuffer.sprintf(__tr("WARNING: cannot open sound card for writing (%s)"), kvi_getErrorString(iError));
+		m_pData->tmpBuffer.sprintf(_i18n_("WARNING: cannot open sound card for writing (%s)"), kvi_getErrorString(iError));
 		KviDccEvent *ev = new KviDccEvent(KVI_DCC_EVENT_MSG, m_pData->tmpBuffer.ptr());
 		KviApplication::postEvent(m_pData->parent, ev);
 
@@ -388,7 +388,7 @@ void KviDccVoiceThread::playbackLoop()
 		m_pData->soundFd = -1;
 	}
 
-	m_pData->tmpBuffer.sprintf(__tr("Buffered: %d milliseconds"), m_pData->recvQueueCount * 128);
+	m_pData->tmpBuffer.sprintf(_i18n_("Buffered: %d milliseconds"), m_pData->recvQueueCount * 128);
 	ev = new KviDccEvent(KVI_DCC_EVENT_BUFFEREDTIME, m_pData->tmpBuffer.ptr());
 	KviApplication::postEvent(m_pData->parent, ev);
 
@@ -509,12 +509,12 @@ void KviDccVoiceAcceptThread::run()
 	m_socket = socket(PF_INET, SOCK_STREAM, 0);
 
 	if( m_socket < 0 ) {
-		abort(__tr("Unable to create a stream socket. DCC voice failed"), m_pData->parent);
+		abort(_i18n_("Unable to create a stream socket. DCC voice failed"), m_pData->parent);
 		return;
 	}
 
 	if( fcntl(m_socket, F_SETFL, O_NONBLOCK) < 0 ) {
-		abort(__tr("Unable to create a non-blocking stream socket. DCC voice failed"), m_pData->parent);
+		abort(_i18n_("Unable to create a non-blocking stream socket. DCC voice failed"), m_pData->parent);
 		return;
 	}
 
@@ -524,24 +524,24 @@ void KviDccVoiceAcceptThread::run()
 	int iError = connect((struct sockaddr *) (&hostSockAddr), sizeof(hostSockAddr));
 
 	if( iError != KVI_ERROR_Success ) {
-		m_pData->tmpBuffer.sprintf(__tr("CONNECT ERROR: %s"), kvi_getErrorString(iError));
+		m_pData->tmpBuffer.sprintf(_i18n_("CONNECT ERROR: %s"), kvi_getErrorString(iError));
 		abort(m_pData->tmpBuffer.ptr(), m_pData->parent);
 		return;
 	}
 
 	// Now wait for connection...
-	KviStr tmp(KviStr::Format, __tr("Connecting to %s on port %u"), m_pData->szAddress.ptr(), m_pData->uPort);
+	KviStr tmp(KviStr::Format, _i18n_("Connecting to %s on port %u"), m_pData->szAddress.ptr(), m_pData->uPort);
 	KviDccEvent *ev = new KviDccEvent(KVI_DCC_EVENT_MSG, tmp.ptr());
 	KviApplication::postEvent(m_pData->parent, ev);
 
 	iError = waitForOutgoingConnection();
 	if( iError != KVI_ERROR_Success ) {
-		m_pData->tmpBuffer.sprintf(__tr("CONNECT ERROR: %s"), kvi_getErrorString(iError));
+		m_pData->tmpBuffer.sprintf(_i18n_("CONNECT ERROR: %s"), kvi_getErrorString(iError));
 		abort(m_pData->tmpBuffer.ptr(), m_pData->parent);
 		return;
 	}
 
-	ev = new KviDccEvent(KVI_DCC_EVENT_MSG, __tr("Connection established"));
+	ev = new KviDccEvent(KVI_DCC_EVENT_MSG, _i18n_("Connection established"));
 	KviApplication::postEvent(m_pData->parent, ev);
 
 	eventLoop();
@@ -578,14 +578,14 @@ void KviDccVoiceRequestThread::run()
 	m_socket = socket(PF_INET, SOCK_STREAM, 0);
 
 	if( m_socket < 0 ) {
-		abort(__tr("Unable to create a listening socket. DCC voice failed"), m_pData->parent);
+		abort(_i18n_("Unable to create a listening socket. DCC voice failed"), m_pData->parent);
 		return;
 	}
 
 	if( m_bStopRequested ) return;
 
 	if( (bind(m_socket, (struct sockaddr *) &sockAddress, sizeof(sockAddress)) < 0) || (listen(m_socket, 100) < 0) ) {
-		abort(__tr("Unable to set up a listening socket. DCC voice failed"), m_pData->parent);
+		abort(_i18n_("Unable to set up a listening socket. DCC voice failed"), m_pData->parent);
 		return;
 	}
 
@@ -593,7 +593,7 @@ void KviDccVoiceRequestThread::run()
 	getsockname(m_socket, (struct sockaddr *) &sockAddress, &iSize);
 	m_pData->uPort = ntohs(sockAddress.sin_port);
 
-	m_pData->tmpBuffer.sprintf(__tr("Listening on port %u"), m_pData->uPort);
+	m_pData->tmpBuffer.sprintf(_i18n_("Listening on port %u"), m_pData->uPort);
 	ev = new KviDccEvent(KVI_DCC_EVENT_MSG, m_pData->tmpBuffer.ptr());
 	KviApplication::postEvent(m_pData->parent, ev);
 
@@ -609,7 +609,7 @@ void KviDccVoiceRequestThread::run()
 	close(m_socket); // Close the old socket...
 	m_socket = newsock;
 
-	m_pData->tmpBuffer.sprintf(__tr("Connected to %s on port %u"), m_pData->szAddress.ptr(), m_pData->uPort);
+	m_pData->tmpBuffer.sprintf(_i18n_("Connected to %s on port %u"), m_pData->szAddress.ptr(), m_pData->uPort);
 	ev = new KviDccEvent(KVI_DCC_EVENT_MSG, m_pData->tmpBuffer.ptr());
 	KviApplication::postEvent(m_pData->parent, ev);
 
