@@ -54,6 +54,7 @@
 #include "kvi_imagelibrary.h"
 #include "kvi_irc_server.h"
 #include "kvi_irc_view.h"
+#include "kvi_jpegio.h"
 #include "kvi_loadscript.h"
 #include "kvi_locale.h"
 #include "kvi_mainmenu.h"
@@ -213,7 +214,7 @@ bool KviApp::setup()
 	// Now we can load the splash image... create the splash screen
 	createSplashScreen();
 	g_setSplashScreenProgress(0);
-	g_setSplashScreenText(__tr("Loading icons..."));
+	g_setSplashScreenText(_i18n_("Loading icons..."));
 	// Now we have a first widget out on the world.
 	g_pIrcViewWidgetList = new QPtrList<KviIrcView>;
 	g_pIrcViewWidgetList->setAutoDelete(false);
@@ -222,7 +223,7 @@ bool KviApp::setup()
 	// Load all our images
 	loadPixmaps(); // 0-13%
 	// Create globals
-	g_setSplashScreenText(__tr("Preparing to parse config files..."));
+	g_setSplashScreenText(_i18n_("Preparing to parse config files..."));
 	// The KviPopups MUST be created before KviOptions (and destroyed after)
 	g_pChannelPopup        = new KviUserPopupMenu(0, "channel_script_popup");
 	g_pConsolePopup        = new KviUserPopupMenu(0, "console_script_popup");
@@ -297,7 +298,7 @@ bool KviApp::setup()
 	g_pWindowPopup     = new KviPopupMenu();
 
 	g_setSplashScreenProgress(88);
-	g_setSplashScreenText(__tr("Booting the nuclear reactor..."));
+	g_setSplashScreenText(_i18n_("Booting the nuclear reactor..."));
 	createQMLProvider();
 	m_szLastHelpDocument = KVI_HELP_QML_MAIN_TOPIC_FILE;
 
@@ -306,7 +307,7 @@ bool KviApp::setup()
 	KviFrame *frm = new KviFrame(); // 89-100 (do not show yet)
 
 	g_setSplashScreenProgress(100);
-	g_setSplashScreenText(__tr("Go!"));
+	g_setSplashScreenText(_i18n_("Go!"));
 
 	destroySplashScreen();
 
@@ -633,7 +634,7 @@ void KviApp::loadPixmaps()
 	KviImageLibrary lib_listbox(szP1.ptr(), szP2.ptr(), 16, 16);
 	g_setSplashScreenProgress(5);
 	if( !lib_listbox.libraryLoaded() )
-		warningBox(__tr("The image library %s cannot be found."), KVI_LISTBOX_IMAGE_LIBRARY_NAME);
+		warningBox(_i18n_("The image library %s cannot be found."), KVI_LISTBOX_IMAGE_LIBRARY_NAME);
 	g_pListBoxOpPixmap     = new QPixmap(lib_listbox.getImage(0));
 	g_pListBoxVoicePixmap  = new QPixmap(lib_listbox.getImage(1));
 	g_pListBoxHelpOpPixmap = new QPixmap(lib_listbox.getImage(2));
@@ -646,7 +647,7 @@ void KviApp::loadPixmaps()
 	KviImageLibrary lib_view(szP1.ptr(), szP2.ptr(), 16, 16);
 	g_setSplashScreenProgress(9);
 	if( !lib_view.libraryLoaded() )
-		warningBox(__tr("The image library %s cannot be found."), KVI_OUT_ICONS_IMAGE_LIBRARY_NAME);
+		warningBox(_i18n_("The image library %s cannot be found."), KVI_OUT_ICONS_IMAGE_LIBRARY_NAME);
 	for( int i = 0; i < KVI_OUT_NUM_IMAGES; i++ )
 		g_pixViewOut[i] = new QPixmap(lib_view.getImage(i));
 	g_setSplashScreenProgress(13);
@@ -693,7 +694,7 @@ void KviApp::saveKVIrcDirectory()
 		__debug_1arg("KVIrc local directory saved to %s", szF.ptr());
 		removeOldConfig();
 	} else {
-		warningBox(__tr("Failed writing the KVIrc home directory path to %s.\n"
+		warningBox(_i18n_("Failed writing the KVIrc home directory path to %s.\n"
 			"You will need to do it manually, otherwise KVIrc will restart with\n"
 			"the setup!"), szF.ptr()
 		);
@@ -795,7 +796,7 @@ void KviApp::warningBox(const char *fmt, ...)
 	// Now m_len is the length of the written string not including the terminator...
 	// Perfect! :)
 	buf = (char *) kvi_realloc(buf, len+1);
-	KviMessageBox::error(buf, _CHAR_2_QSTRING(__tr("KVIrc: WARNING")));
+	KviMessageBox::error(buf, _CHAR_2_QSTRING(_i18n_("KVIrc: WARNING")));
 	kvi_free(buf);
 }
 
@@ -1043,9 +1044,9 @@ void KviApp::slot_scriptWizardFinished(bool bAccepted)
 	}
 	if( bAccepted ) {
 		if( saveScript(&s) )
-			s.pWnd->output(KVI_OUT_INTERNAL, __tr("Script successfully saved"));
+			s.pWnd->output(KVI_OUT_INTERNAL, _i18n_("Script successfully saved"));
 		else
-			s.pWnd->output(KVI_OUT_ERROR, __tr("Failed to save the script"));
+			s.pWnd->output(KVI_OUT_ERROR, _i18n_("Failed to save the script"));
 		if( s.pExtraFilesList ) delete s.pExtraFilesList;
 	}
 }
