@@ -64,7 +64,7 @@ KviConsole::KviConsole(KviFrame *lpFrm)
 	connect(m_pView, SIGNAL(contextPopupRequested(KviIrcView *)), this, SLOT(viewRightClicked(KviIrcView *)));
 	connect(m_pListBox, SIGNAL(rightClicked()), this, SLOT(listBoxRightClicked()));
 
-	QToolTip::add(m_pListBox, __tr("Notify list"));
+	QToolTip::add(m_pListBox, _i18n_("Notify list"));
 }
 
 /**
