@@ -88,7 +88,7 @@ KviPluginData *KviPluginManager::loadPlugin(const char *fName, bool bAutoload, K
 	void *handle = dlopen(fName, RTLD_NOW);
 	if( !handle ) {
 		if( pErrorRet )
-			pErrorRet->sprintf(__tr("dlopen() error: %s"), dlerror());
+			pErrorRet->sprintf(_i18n_("dlopen() error: %s"), dlerror());
 		return 0;
 	}
 
@@ -96,7 +96,7 @@ KviPluginData *KviPluginManager::loadPlugin(const char *fName, bool bAutoload, K
 	if( !description ) {
 		// Not a KVIrc plugin
 		if( pErrorRet )
-			*pErrorRet = __tr("Plugin loaded but exports no 'kvirc_plugin' symbol");
+			*pErrorRet = _i18n_("Plugin loaded but exports no 'kvirc_plugin' symbol");
 		dlclose(handle);
 		return 0;
 	}
