@@ -67,7 +67,7 @@ KviQuery::~KviQuery()
 
 void KviQuery::dndEnteredView()
 {
-	m_pFrm->m_pStatusBar->tempText(__tr("Drop the file to start the DCC Send"), 5000);
+	m_pFrm->m_pStatusBar->tempText(_i18n_("Drop the file to start the DCC Send"), 5000);
 }
 
 void KviQuery::fileDroppedOnView(const char *fileName)
