@@ -229,11 +229,11 @@ bool KviRegisteredUsersDb::load(const char *filename, KviStr &error)
 {
 	KviStr buffer;
 	if( !kvi_loadFile(filename, buffer) ) {
-		error = __tr("Unable to load file");
+		error = _i18n_("Unable to load file");
 		return false;
 	}
 	if( !kvi_strEqualCSN(KVI_MAGIC_STRING, buffer.ptr(), KVI_MAGIC_STRING_LENGTH) ) {
-		error = __tr("Invalid magic");
+		error = _i18n_("Invalid magic");
 		return false; // Not a KVIrc file
 	}
 	buffer.cutLeft(KVI_MAGIC_STRING_LENGTH);
