@@ -375,14 +375,14 @@ bool KviUserPopupMenu::loadAllPopups(const char *filename, KviStr &error)
 			target = g_pDccChatPopup;
 			buffer.cutLeft(7);
 		} else {
-			error = __tr("Unknown popup name");
+			error = _i18n_("Unknown popup name");
 			__debug(buffer.ptr());
 			return false;
 		}
 
 		buffer.stripLeftWhiteSpace();
 		if( !kvi_strEqualNoLocaleCIN("bytes ", buffer.ptr(), 6) ) {
-			error = __tr("Syntax error in POPUP label");
+			error = _i18n_("Syntax error in POPUP label");
 			__debug(buffer.ptr());
 			return false;
 		}
@@ -426,14 +426,14 @@ bool KviUserPopupMenu::loadAllPopups(const char *filename, KviStr &error)
 		buffer.stripLeftWhiteSpace();
 
 		if( !kvi_strEqualCSN("[ENDPOPUP]\n", buffer.ptr(), 11) ) {
-			error = __tr("Something went wrong with the popup buffer length");
+			error = _i18n_("Something went wrong with the popup buffer length");
 			__debug(buffer.ptr());
 			return false;
 		}
 		buffer.cutLeft(11);
 
 		if( target->m_bLocked ) {
-			error = __tr("Attempted to modify a locked popup");
+			error = _i18n_("Attempted to modify a locked popup");
 			debug("WARNING: attempted to modify locked popup, skipping");
 			return false;
 		}
@@ -480,34 +480,34 @@ bool KviUserPopupMenu::loadFromDataBuffer(KviStr &buffer, KviStr &error)
 			buffer.cutLeft(7);
 			KviStr image, name, bytes;
 			if( !buffer.getLine(image) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 			buffer.stripLeftWhiteSpace();
 			if( !buffer.getLine(name) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 			buffer.stripLeftWhiteSpace();
 			if( !buffer.getLine(bytes) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 
 			if( !kvi_strEqualNoLocaleCIN("image=", image.ptr(), 6) ) {
-				error = __tr("Unrecognized item image label");
+				error = _i18n_("Unrecognized item image label");
 				return false;
 			}
 			image.cutLeft(6);
 			image.stripWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("name=", name.ptr(), 5) ) {
-				error = __tr("Unrecognized item name label");
+				error = _i18n_("Unrecognized item name label");
 				return false;
 			}
 			name.cutLeft(5);
 			name.stripWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("bytes=", bytes.ptr(), 6) ) {
-				error = __tr("Unrecognized item length label");
+				error = _i18n_("Unrecognized item length label");
 				return false;
 			}
 			bytes.cutLeft(6);
@@ -515,18 +515,18 @@ bool KviUserPopupMenu::loadFromDataBuffer(KviStr &buffer, KviStr &error)
 			bool bOk = false;
 			int bLen = bytes.toInt(&bOk);
 			if( !bOk ) {
-				error = __tr("Unrecognized item length");
+				error = _i18n_("Unrecognized item length");
 				return false;
 			}
 			if( (bLen < 0) || (bLen > buffer.len()) ) {
-				error = __tr("Buffer is shorter than the declared length");
+				error = _i18n_("Buffer is shorter than the declared length");
 				return false;
 			}
 			KviStr pBuf = buffer.left(bLen);
 			buffer.cutLeft(bLen);
 			buffer.stripLeftWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("[enditem]\n", buffer.ptr(), 10) ) {
-				error = __tr("Something went wrong with the buffer length");
+				error = _i18n_("Something went wrong with the buffer length");
 				return false;
 			}
 			buffer.cutLeft(10);
@@ -535,34 +535,34 @@ bool KviUserPopupMenu::loadFromDataBuffer(KviStr &buffer, KviStr &error)
 			buffer.cutLeft(10);
 			KviStr image, szName, bytes;
 			if( !buffer.getLine(image) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 			buffer.stripLeftWhiteSpace();
 			if( !buffer.getLine(szName) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 			buffer.stripLeftWhiteSpace();
 			if( !buffer.getLine(bytes) ) {
-				error = __tr("Unexpected end of buffer");
+				error = _i18n_("Unexpected end of buffer");
 				return false;
 			}
 
 			if( !kvi_strEqualNoLocaleCIN("image=", image.ptr(), 6) ) {
-				error = __tr("Unrecognized submenu image label");
+				error = _i18n_("Unrecognized submenu image label");
 				return false;
 			}
 			image.cutLeft(6);
 			image.stripWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("name=", szName.ptr(), 5) ) {
-				error = __tr("Unrecognized submenu name label");
+				error = _i18n_("Unrecognized submenu name label");
 				return false;
 			}
 			szName.cutLeft(5);
 			szName.stripWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("bytes=", bytes.ptr(), 6) ) {
-				error = __tr("Unrecognized submenu length label");
+				error = _i18n_("Unrecognized submenu length label");
 				return false;
 			}
 			bytes.cutLeft(6);
@@ -570,18 +570,18 @@ bool KviUserPopupMenu::loadFromDataBuffer(KviStr &buffer, KviStr &error)
 			bool bOk = false;
 			int bLen = bytes.toInt(&bOk);
 			if( !bOk ) {
-				error = __tr("Unrecognized submenu length");
+				error = _i18n_("Unrecognized submenu length");
 				return false;
 			}
 			if( (bLen < 0) || (bLen > buffer.len()) ) {
-				error = __tr("Buffer is shorter than the declared length");
+				error = _i18n_("Buffer is shorter than the declared length");
 				return false;
 			}
 			KviStr mBuf = buffer.left(bLen);
 			buffer.cutLeft(bLen);
 			buffer.stripLeftWhiteSpace();
 			if( !kvi_strEqualNoLocaleCIN("[endsubmenu]\n", buffer.ptr(), 13) ) {
-				error = __tr("Something went wrong with the buffer length");
+				error = _i18n_("Something went wrong with the buffer length");
 				return false;
 			}
 			buffer.cutLeft(13);
@@ -596,7 +596,7 @@ bool KviUserPopupMenu::loadFromDataBuffer(KviStr &buffer, KviStr &error)
 			insertPopupItem(szName.ptr(), image.ptr(), menu);
 			idx++;
 		} else {
-			error = __tr("Unrecognized popup item");
+			error = _i18n_("Unrecognized popup item");
 			return false;
 		}
 		buffer.stripLeftWhiteSpace();
