@@ -51,7 +51,7 @@
 KviWindow::KviWindow(const char *name, int type, KviFrame *lpFrm)
 	: QWidget(0, name)
 {
-	m_szCaption         = name ? name : __tr("Unnamed");
+	m_szCaption         = name ? name : _i18n_("Unnamed");
 	m_pFrm              = lpFrm;
 	m_type              = type;
 	m_pTaskBarButton    = 0;
@@ -376,7 +376,7 @@ void KviWindow::setFocusHandler(QWidget *w)
  */
 void KviWindow::youAreAttached(KviMdiChild *lpC)
 {
-	lpC->setCaption(m_szCaption.ptr());
+	lpC->setCaption(m_szCaption);
 	lpC->setIconPointer(myIconPtr()); // It is OK to set a null icon here
 }
 
@@ -385,7 +385,7 @@ void KviWindow::youAreAttached(KviMdiChild *lpC)
  */
 void KviWindow::youAreDetached()
 {
-	setCaption(m_szCaption.ptr());
+	setCaption(m_szCaption);
 	if( myIconPtr() )
 		setIcon(*(myIconPtr()));
 	setFocusPolicy(StrongFocus);
@@ -398,10 +398,10 @@ void KviWindow::setWindowCaption(const char *szCaption)
 {
 	m_szCaption = szCaption;
 	if( mdiParent() ) {
-		mdiParent()->setCaption(m_szCaption.ptr());
+		mdiParent()->setCaption(m_szCaption);
 		if( isMaximized() )
 			m_pFrm->updateCaption();
-	} else setCaption(m_szCaption.ptr());
+	} else setCaption(m_szCaption);
 	if( m_pTaskBarButton )
 		m_pTaskBarButton->updateButton();
 }
