@@ -105,11 +105,11 @@ KviPopupEditor::KviPopupEditor(QWidget *parent, const char *name)
 
 	QGridLayout *g = new QGridLayout(this, 4, 4, 4, 2);
 
-	KviPushButton *b = new KviPushButton(_CHAR_2_QSTRING(__tr("&Test Popup")), this);
+	KviPushButton *b = new KviPushButton(_CHAR_2_QSTRING(_i18n_("&Test Popup")), this);
 	g->addWidget(b, 0, 2);
 	connect(b, SIGNAL(clicked()), this, SLOT(testCurrentPopup()));
 
-	b = new KviPushButton(_CHAR_2_QSTRING(__tr("&Clear Popup")), this);
+	b = new KviPushButton(_CHAR_2_QSTRING(_i18n_("&Clear Popup")), this);
 	g->addWidget(b, 0, 3);
 	connect(b, SIGNAL(clicked()), this, SLOT(clearCurrentPopup()));
 
@@ -154,7 +154,7 @@ KviPopupEditor::KviPopupEditor(QWidget *parent, const char *name)
 		ppp->insertItem(*(g_pixViewOut[i]), i);
 		if( ((i % 15) == 0) && (i != 0) ) {
 			KviPopupMenu *sub = new KviPopupMenu(ppp);
-			ppp->insertItem(__tr("More..."), sub);
+			ppp->insertItem(_i18n_("More..."), sub);
 			ppp = sub;
 			connect(ppp, SIGNAL(activated(int)), this, SLOT(iconPopupActivated(int)));
 		}
@@ -294,8 +294,8 @@ void KviPopupEditor::testCurrentPopup()
 void KviPopupEditor::clearCurrentPopup()
 {
 	if( KviMessageBox::warningYesNo(
-		__tr("Are you sure you want to clear this popup?"),
-		__tr("Clear Popup"),
+		_i18n_("Are you sure you want to clear this popup?"),
+		_i18n_("Clear Popup"),
 		this) == KviMessageBox::Yes
 	) {
 		m_pPopupView->clear();
@@ -356,13 +356,13 @@ void KviPopupEditor::saveSubmenu(KviUserPopupMenu *p, KviPopupListViewItem *par)
 				KviStr tmp = it->text(0);
 				tmp.stripWhiteSpace();
 				if( tmp.isEmpty() )
-					tmp = __tr("Unnamed");
+					tmp = _i18n_("Unnamed");
 				it->m_id = p->insertNormalItem(tmp.ptr(), it->m_icon.ptr(), it->m_buffer.ptr());
 			} else {
 				KviStr tmp = it->text(0);
 				tmp.stripWhiteSpace();
 				if( tmp.isEmpty() )
-					tmp = __tr("Unnamed");
+					tmp = _i18n_("Unnamed");
 				KviStr yourName(KviStr::Format, "usertoolbar_script_popup_%s", tmp.ptr());
 				KviUserPopupMenu *sub = new KviUserPopupMenu(0, yourName.ptr());
 				saveSubmenu(sub, it);
@@ -519,7 +519,7 @@ void KviPopupEditor::savePopupItem(KviPopupListViewItem *p)
 		QString s = m_pPopupNameEditor->text();
 		s.stripWhiteSpace();
 		if( s.isEmpty() )
-			s = _CHAR_2_QSTRING(__tr("Unnamed"));
+			s = _CHAR_2_QSTRING(_i18n_("Unnamed"));
 		m_pEditedPopupItem->setText(0, s);
 		m_pEditedPopupItem->tryLoadImage();
 	} else if( m_pEditedPopupItem->m_type == KviPopupListViewItem::Submenu ) {
@@ -527,7 +527,7 @@ void KviPopupEditor::savePopupItem(KviPopupListViewItem *p)
 		QString s = m_pPopupNameEditor->text();
 		s.stripWhiteSpace();
 		if( s.isEmpty() )
-			s = _CHAR_2_QSTRING(__tr("Unnamed"));
+			s = _CHAR_2_QSTRING(_i18n_("Unnamed"));
 		m_pEditedPopupItem->setText(0, s);
 		m_pEditedPopupItem->tryLoadImage();
 	}
@@ -546,38 +546,38 @@ void KviPopupEditor::popupViewRightButtonPressed(KviListViewItem *i, const QPoin
 
 	if( m_pEditedPopupItem ) {
 		m_pPopupPopup->clear();
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("&Remove Item")), this, SLOT(removeEditedPopupItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Remove Item")), this, SLOT(removeEditedPopupItem()));
 		m_pPopupPopup->insertSeparator();
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("&Add Item Below")), this, SLOT(addEmptyPopupItem()));
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add &Submenu Below")), this, SLOT(addSubmenuItem()));
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&eparator Below")), this, SLOT(addSeparatorItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Add Item Below")), this, SLOT(addEmptyPopupItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add &Submenu Below")), this, SLOT(addSubmenuItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&eparator Below")), this, SLOT(addSeparatorItem()));
 		if( m_pEditedPopupItem->parent() == m_pEditedPopupItem->itemAbove() ) {
 			m_pPopupPopup->insertSeparator();
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("A&dd Item Above")), this, SLOT(addEmptyPopupItemAbove()));
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&ubmenu Above")), this, SLOT(addSubmenuItemAbove()));
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add Separat&or Above")), this, SLOT(addSeparatorItemAbove()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("A&dd Item Above")), this, SLOT(addEmptyPopupItemAbove()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&ubmenu Above")), this, SLOT(addSubmenuItemAbove()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add Separat&or Above")), this, SLOT(addSeparatorItemAbove()));
 		}
 		if( m_pEditedPopupItem->m_type == KviPopupListViewItem::Submenu ) {
 			m_pPopupPopup->insertSeparator();
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add I&tem Inside")), this, SLOT(addEmptyPopupItemInside()));
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add Su&bmenu Inside")), this, SLOT(addSubmenuItemInside()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add I&tem Inside")), this, SLOT(addEmptyPopupItemInside()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add Su&bmenu Inside")), this, SLOT(addSubmenuItemInside()));
 		}
 		m_pPopupPopup->insertSeparator();
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("&Copy Item")), this, SLOT(copyItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Copy Item")), this, SLOT(copyItem()));
 		if( m_pClipboardItem ) {
-			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("&Paste Item Below")), this, SLOT(pasteItemBelow()));
+			m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Paste Item Below")), this, SLOT(pasteItemBelow()));
 			if( m_pEditedPopupItem->parent() == m_pEditedPopupItem->itemAbove() )
-				m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Paste &Item Above")), this, SLOT(pasteItemAbove()));
+				m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Paste &Item Above")), this, SLOT(pasteItemAbove()));
 			if( m_pEditedPopupItem->m_type == KviPopupListViewItem::Submenu )
-				m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Paste Item I&nside")), this, SLOT(pasteItemInside()));
+				m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Paste Item I&nside")), this, SLOT(pasteItemInside()));
 		}
 	} else {
 		// At the end?
 		disablePopupEditors();
 		m_pPopupPopup->clear();
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("&Add Item")), this, SLOT(addEmptyPopupItem()));
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add &Submenu")), this, SLOT(addSubmenuItem()));
-		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&eparator")), this, SLOT(addSeparatorItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Add Item")), this, SLOT(addEmptyPopupItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add &Submenu")), this, SLOT(addSubmenuItem()));
+		m_pPopupPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&eparator")), this, SLOT(addSeparatorItem()));
 	}
 	m_pPopupPopup->popup(p);
 }
@@ -619,18 +619,18 @@ void KviPopupEditor::addEmptyPopupItem()
 			it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 				((KviPopupListViewItem *) m_pEditedPopupItem->parent()),
 				m_pEditedPopupItem, "unnamed", "item",
-				__tr("# Enter the script for the new item here"), ""
+				_i18n_("# Enter the script for the new item here"), ""
 			);
 		} else {
 			it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 				m_pPopupView, m_pEditedPopupItem, "unnamed", "item",
-				__tr("# Enter the script for the new item here"), ""
+				_i18n_("# Enter the script for the new item here"), ""
 			);
 		}
 	} else {
 		it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 			m_pPopupView, "unnamed", "item",
-			__tr("# Enter the script for the new item here"), ""
+			_i18n_("# Enter the script for the new item here"), ""
 		);
 	}
 	m_pPopupView->setSelected(it, true);
@@ -735,13 +735,13 @@ void KviPopupEditor::addEmptyPopupItemAbove()
 		it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 			((KviPopupListViewItem *) m_pEditedPopupItem->parent()),
 			0, "unnamed", "item",
-			__tr("# Enter the script for the new item here"), ""
+			_i18n_("# Enter the script for the new item here"), ""
 		);
 	} else {
 		it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 			m_pPopupView,
 			0, "unnamed", "item",
-			__tr("# Enter the script for the new item here"), ""
+			_i18n_("# Enter the script for the new item here"), ""
 		);
 	}
 	m_pPopupView->setSelected(it, true);
@@ -770,7 +770,7 @@ void KviPopupEditor::addSubmenuItemAbove()
 	KviPopupListViewItem *it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 		sb,
 		"unnamed", "item",
-		__tr("# Enter the script for the new item here"), ""
+		_i18n_("# Enter the script for the new item here"), ""
 	);
 	sb->setOpen(true);
 
@@ -809,7 +809,7 @@ void KviPopupEditor::addEmptyPopupItemInside()
 
 	KviPopupListViewItem *it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 		m_pEditedPopupItem, "unnamed", "item",
-		__tr("# Enter the script for the new item here"), ""
+		_i18n_("# Enter the script for the new item here"), ""
 	);
 	m_pPopupView->setSelected(it, true);
 }
@@ -823,7 +823,7 @@ void KviPopupEditor::addSubmenuItemInside()
 	);
 	KviPopupListViewItem *it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 		sb, "unnamed", "item",
-		__tr("# Enter the script for the new item here"), ""
+		_i18n_("# Enter the script for the new item here"), ""
 	);
 	sb->setOpen(true);
 	m_pPopupView->setSelected(it, true);
@@ -852,7 +852,7 @@ void KviPopupEditor::addSubmenuItem()
 
 	KviPopupListViewItem *it = new KviPopupListViewItem(KviPopupListViewItem::Item,
 		sb, "unnamed", "item",
-		__tr("# Enter the script for the new item here"), ""
+		_i18n_("# Enter the script for the new item here"), ""
 	);
 	sb->setOpen(true);
 
