@@ -83,7 +83,7 @@ KviUserToolBarEditor::KviUserToolBarEditor(QWidget *parent, const char *name)
 	m_pToolBar->setStretchableWidget(new KviTransparentWidget(m_pToolBar));
 	g->addMultiCellWidget(m_pToolBar, 0, 0, 0, 1);
 
-	KviPushButton *b = new KviPushButton(_CHAR_2_QSTRING(__tr("&Clear Toolbar")), this);
+	KviPushButton *b = new KviPushButton(_CHAR_2_QSTRING(_i18n_("&Clear Toolbar")), this);
 	g->addWidget(b, 0, 2);
 	connect(b, SIGNAL(clicked()), this, SLOT(clearToolBar()));
 
@@ -91,8 +91,8 @@ KviUserToolBarEditor::KviUserToolBarEditor(QWidget *parent, const char *name)
 	splitter->setOpaqueResize();
 
 	m_pToolBarView = new KviListView(splitter);
-	m_pToolBarView->addColumn(_CHAR_2_QSTRING(__tr("Item")));
-	m_pToolBarView->addColumn(_CHAR_2_QSTRING(__tr("Type")));
+	m_pToolBarView->addColumn(_CHAR_2_QSTRING(_i18n_("Item")));
+	m_pToolBarView->addColumn(_CHAR_2_QSTRING(_i18n_("Type")));
 	m_pToolBarView->setRootIsDecorated(true);
 	m_pToolBarView->setMultiSelection(false);
 	m_pToolBarView->header()->setClickEnabled(false);
@@ -117,7 +117,7 @@ KviUserToolBarEditor::KviUserToolBarEditor(QWidget *parent, const char *name)
 		ppp->insertItem(*(g_pixViewOut[i]), i);
 		if( ((i % 24) == 0) && (i != 0) ) {
 			KviPopupMenu *sub = new KviPopupMenu(ppp);
-			ppp->insertItem(__tr("More..."), sub);
+			ppp->insertItem(_i18n_("More..."), sub);
 			ppp = sub;
 			connect(ppp, SIGNAL(activated(int)), this, SLOT(iconPopupActivated(int)));
 		}
@@ -137,7 +137,7 @@ KviUserToolBarEditor::KviUserToolBarEditor(QWidget *parent, const char *name)
 	m_pIconButton->setFocusPolicy(NoFocus);
 	connect(m_pIconButton, SIGNAL(clicked()), this, SLOT(popupIconMenu()));
 
-	m_pBrowseButton = new KviPushButton(_CHAR_2_QSTRING(__tr("&Browse...")), box);
+	m_pBrowseButton = new KviPushButton(_CHAR_2_QSTRING(_i18n_("&Browse...")), box);
 	m_pBrowseButton->setFocusPolicy(NoFocus);
 	connect(m_pBrowseButton, SIGNAL(clicked()), this, SLOT(pickIconFilename()));
 
@@ -263,8 +263,8 @@ void KviUserToolBarEditor::startEditToolBar(KviUserToolBar *p)
 void KviUserToolBarEditor::clearToolBar()
 {
 	if( KviMessageBox::warningYesNo(
-		__tr("Are you sure you want to clear the user toolbar?"),
-		__tr("Clear User Toolbar"),
+		_i18n_("Are you sure you want to clear the user toolbar?"),
+		_i18n_("Clear User Toolbar"),
 		this) == KviMessageBox::Yes
 	) {
 		m_pToolBarView->clear();
@@ -324,7 +324,7 @@ void KviUserToolBarEditor::saveToolButton(KviToolBarListViewItem *p)
 		QString s = m_pToolBarNameEditor->text();
 		s.stripWhiteSpace();
 		if( s.isEmpty() )
-			s = _CHAR_2_QSTRING(__tr("Unnamed"));
+			s = _CHAR_2_QSTRING(_i18n_("Unnamed"));
 		m_pEditedToolButton->setText(0, s);
 		m_pEditedToolButton->tryLoadImage();
 	} else if( m_pEditedToolButton->m_type == KviToolBarListViewItem::Submenu ) {
@@ -332,7 +332,7 @@ void KviUserToolBarEditor::saveToolButton(KviToolBarListViewItem *p)
 		QString s = m_pToolBarNameEditor->text();
 		s.stripWhiteSpace();
 		if( s.isEmpty() )
-			s = _CHAR_2_QSTRING(__tr("Unnamed"));
+			s = _CHAR_2_QSTRING(_i18n_("Unnamed"));
 		m_pEditedToolButton->setText(0, s);
 		m_pEditedToolButton->tryLoadImage();
 	}
@@ -351,13 +351,13 @@ void KviUserToolBarEditor::saveToolBarMenu(KviUserPopupMenu *p, KviToolBarListVi
 				KviStr tmp = it->text(0);
 				tmp.stripWhiteSpace();
 				if( tmp.isEmpty() )
-					tmp = __tr("Unnamed");
+					tmp = _i18n_("Unnamed");
 				it->m_id = p->insertNormalItem(tmp.ptr(), it->m_icon.ptr(), it->m_buffer.ptr());
 			} else if( it->m_type == KviToolBarListViewItem::Menu ) {
 				KviStr tmp = it->text(0);
 				tmp.stripWhiteSpace();
 				if( tmp.isEmpty() )
-					tmp = __tr("Unnamed");
+					tmp = _i18n_("Unnamed");
 				KviStr yourName(KviStr::Format, "usertoolbar_script_popup_%s", tmp.ptr());
 
 				KviUserPopupMenu *sub = new KviUserPopupMenu(0, yourName.ptr());
@@ -388,14 +388,14 @@ void KviUserToolBarEditor::updateToolBar(KviUserToolBar *p, KviToolBarListViewIt
 			KviStr tmp = it->text(0);
 			tmp.stripWhiteSpace();
 			if( tmp.isEmpty() )
-				tmp = __tr("Unnamed");
+				tmp = _i18n_("Unnamed");
 			p->insertNormalItem(tmp.ptr(), it->m_sbar.ptr(), it->m_icon.ptr(), it->m_buffer.ptr());
 		} else
 		if( it->m_type == KviToolBarListViewItem::Menu ) {
 			KviStr tmp = it->text(0);
 			tmp.stripWhiteSpace();
 			if( tmp.isEmpty() )
-				tmp = __tr("Unnamed");
+				tmp = _i18n_("Unnamed");
 			KviStr yourName(KviStr::Format, "usertoolbar_script_popup_%s", tmp.ptr());
 			KviUserPopupMenu *m = new KviUserPopupMenu(0, yourName.ptr());
 			saveToolBarMenu(m, it);
@@ -607,36 +607,36 @@ void KviUserToolBarEditor::toolBarViewRightButtonPressed(KviListViewItem *i, con
 
 	if( m_pEditedToolButton ) {
 		m_pToolBarPopup->clear();
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("&Remove Item")), this, SLOT(removeEditedToolButton()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Remove Item")), this, SLOT(removeEditedToolButton()));
 		m_pToolBarPopup->insertSeparator();
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("&Add Item Below")), this, SLOT(addEmptyToolButton()));
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add &Submenu Below")), this, SLOT(addToolBarMenu()));
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&eparator Below")), this, SLOT(addToolBarSeparatorItem()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Add Item Below")), this, SLOT(addEmptyToolButton()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add &Submenu Below")), this, SLOT(addToolBarMenu()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&eparator Below")), this, SLOT(addToolBarSeparatorItem()));
 		if( m_pEditedToolButton->parent() == m_pEditedToolButton->itemAbove() ) {
 			m_pToolBarPopup->insertSeparator();
-			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("A&dd Item Above")), this, SLOT(addEmptyToolButtonAbove()));
-			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&ubmenu Above")), this, SLOT(addToolBarMenuAbove()));
-			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add Separat&or Above")), this, SLOT(addToolBarSeparatorItemAbove()));
+			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("A&dd Item Above")), this, SLOT(addEmptyToolButtonAbove()));
+			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&ubmenu Above")), this, SLOT(addToolBarMenuAbove()));
+			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add Separat&or Above")), this, SLOT(addToolBarSeparatorItemAbove()));
 		}
 		if( m_pEditedToolButton->m_type == KviToolBarListViewItem::Button ||
 		    m_pEditedToolButton->m_type == KviToolBarListViewItem::Item
 		) {
 			m_pToolBarPopup->insertSeparator();
-			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("&Copy Item")), this, SLOT(copyToolButton()));
+			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Copy Item")), this, SLOT(copyToolButton()));
 		}
 		if( m_szClipboardItemName.hasData() ) {
-			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("&Paste Item Below")), this, SLOT(pasteToolButtonBelow()));
+			m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Paste Item Below")), this, SLOT(pasteToolButtonBelow()));
 			if( m_pEditedToolButton->parent() == m_pEditedToolButton->itemAbove() ) {
-				m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Paste &Item Above")), this, SLOT(pasteToolButtonAbove()));
+				m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Paste &Item Above")), this, SLOT(pasteToolButtonAbove()));
 			}
 		}
 	} else {
 		// At the end?
 		disableToolBarEditors();
 		m_pToolBarPopup->clear();
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("&Add Item")), this, SLOT(addEmptyToolButton()));
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add &Submenu")), this, SLOT(addToolBarMenu()));
-		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(__tr("Add S&eparator")), this, SLOT(addToolBarSeparatorItem()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("&Add Item")), this, SLOT(addEmptyToolButton()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add &Submenu")), this, SLOT(addToolBarMenu()));
+		m_pToolBarPopup->insertItem(_CHAR_2_QSTRING(_i18n_("Add S&eparator")), this, SLOT(addToolBarSeparatorItem()));
 	}
 	m_pToolBarPopup->popup(p);
 }
@@ -695,19 +695,19 @@ void KviUserToolBarEditor::addEmptyToolButton()
 			it = new KviToolBarListViewItem(KviToolBarListViewItem::Item,
 				(KviToolBarListViewItem *) m_pEditedToolButton->parent(),
 				m_pEditedToolButton, "unnamed", "item",
-				__tr("# Enter the script for the new item here"), ""
+				_i18n_("# Enter the script for the new item here"), ""
 			);
 		} else {
 			it = new KviToolBarListViewItem(KviToolBarListViewItem::Button,
 				m_pToolBarView,
 				m_pEditedToolButton, "unnamed", "button",
-				__tr("# Enter the script for the new item here"), ""
+				_i18n_("# Enter the script for the new item here"), ""
 			);
 		}
 	} else {
 		it = new KviToolBarListViewItem(KviToolBarListViewItem::Button,
 			m_pToolBarView, "unnamed", "button",
-			__tr("# Enter the script for the new item here"), ""
+			_i18n_("# Enter the script for the new item here"), ""
 		);
 	}
 	m_pToolBarView->setSelected(it, true);
@@ -736,7 +736,7 @@ void KviUserToolBarEditor::addToolBarMenu()
 	}
 
 	KviToolBarListViewItem *it = new KviToolBarListViewItem(KviToolBarListViewItem::Item,
-		sb, "unnamed", "item", __tr("# Enter the script for the new item here"), ""
+		sb, "unnamed", "item", _i18n_("# Enter the script for the new item here"), ""
 	);
 	sb->setOpen(true);
 
@@ -764,7 +764,7 @@ void KviUserToolBarEditor::addToolBarMenuAbove()
 	}
 
 	KviToolBarListViewItem *it = new KviToolBarListViewItem(KviToolBarListViewItem::Item,
-		sb, "unnamed", "item", __tr("# Enter the script for the new item here"), ""
+		sb, "unnamed", "item", _i18n_("# Enter the script for the new item here"), ""
 	);
 	sb->setOpen(true);
 
@@ -846,12 +846,12 @@ void KviUserToolBarEditor::addEmptyToolButtonAbove()
 	if( m_pEditedToolButton->parent() ) {
 		it = new KviToolBarListViewItem(KviToolBarListViewItem::Item,
 			(KviToolBarListViewItem *) m_pEditedToolButton->parent(),
-			"unnamed", "item", __tr("# Enter the script for the new item here"), "", ""
+			"unnamed", "item", _i18n_("# Enter the script for the new item here"), "", ""
 		);
 	} else {
 		it = new KviToolBarListViewItem(KviToolBarListViewItem::Button,
 			m_pToolBarView,
-			"unnamed", "button", __tr("# Enter the script for the new item here"), "", ""
+			"unnamed", "button", _i18n_("# Enter the script for the new item here"), "", ""
 		);
 	}
 	m_pToolBarView->setSelected(it, true);
@@ -892,7 +892,7 @@ void KviUserToolBarEditor::addToolBarSeparatorItem()
 		if( m_pEditedToolButton->parent() ) {
 			it = new KviToolBarListViewItem(KviToolBarListViewItem::Separator,
 				(KviToolBarListViewItem *) m_pEditedToolButton->parent(),
-				m_pEditedToolButton, "----", "separator", __tr("# Enter the script for the new item here"), ""
+				m_pEditedToolButton, "----", "separator", _i18n_("# Enter the script for the new item here"), ""
 			);
 		} else {
 			it = new KviToolBarListViewItem(KviToolBarListViewItem::Separator,
