@@ -197,7 +197,7 @@ bool KviBiff::checkMailbox(KviBiffMailbox *mbox)
 
 	if( !m_pSocket->run(mbox) ) {
 	    // Failure!
-	    systrayMsg(__tr("Failed to startup mail checking!"));
+	    systrayMsg(_i18n_("Failed to startup mail checking!"));
 	    delete m_pSocket;
 	    m_pSocket = 0;
 	    return false;
@@ -212,7 +212,7 @@ void KviBiff::socketResolving()
 	if( !m_pCurMailbox ) return;
 
 	KviStr s;
-	s.sprintf("Resolving host %s", m_pCurMailbox->hostname());
+	s.sprintf("Resolving host %s",  m_pCurMailbox->hostname());
 	systrayMsg(s.ptr());
 }
 
@@ -220,7 +220,7 @@ void KviBiff::socketConnected()
 {
 	for( KviBiffSysTray *w = m_pBiffWidgetList->first(); w; w = m_pBiffWidgetList->next() ) {
 	    KviStr s;
-	    s.sprintf(__tr("Connected to %s (%s) on port %d, logging in."),
+	    s.sprintf(_i18n_("Connected to %s (%s) on port %d, logging in."),
 			m_pSocket->hostname(), m_pSocket->hostIp(), m_pSocket->port());
 	    systrayMsg(s.ptr());
 	}
@@ -231,7 +231,7 @@ void KviBiff::socketLoggedIn()
 	if( !m_pCurMailbox ) return;
 
 	KviStr s;
-	s.sprintf(__tr("Logged in to %s as %s, checking for new mail..."),
+	s.sprintf(_i18n_("Logged in to %s as %s, checking for new mail..."),
 		m_pCurMailbox->hostname(), m_pCurMailbox->username());
 	systrayMsg(s.ptr(), 1, true);
 }
@@ -247,7 +247,7 @@ void KviBiff::socketError(const char *err)
 	if( !m_pCurMailbox ) return;
 
 	KviStr s;
-	s.sprintf(__tr("Error while checking mail at %s@%s:\n%s"),
+	s.sprintf(_i18n_("Error while checking mail at %s@%s:\n%s"),
 	    m_pCurMailbox->username(), m_pCurMailbox->hostname(), err);
 	systrayMsg(s.ptr());
 
@@ -265,19 +265,19 @@ void KviBiff::socketJobDone()
 	uint msg_count = m_pCurMailbox->messageCount();
 	KviStr msg;
 	if( msg_count == 0 ) {
-	    msg.sprintf(__tr("There are no messages in %s@%s."),
+	    msg.sprintf(_i18n_("There are no messages in %s@%s."),
 	        m_pCurMailbox->username(), m_pCurMailbox->hostname());
 	    m_pCurrentIcon = g_iconNormal;
 	} else
 	{
 	    if( msg_count == 1 ) {
 	        msg.sprintf(
-				__tr("There is 1 message in %s@%s."),
+				_i18n_("There is 1 message in %s@%s."),
 	            m_pCurMailbox->username(), m_pCurMailbox->hostname()
 			);
 	    } else {
 	        msg.sprintf(
-				__tr("There are %u messages in %s@%s."),
+				_i18n_("There are %u messages in %s@%s."),
 	            msg_count, m_pCurMailbox->username(), m_pCurMailbox->hostname()
 			);
 		}
@@ -484,7 +484,7 @@ const KviBiffMailbox *const KviBiff::findMailbox(const char *username, const cha
 void KviBiff::slotCheckMailIn(int idx)
 {
 	if( m_pSocket ) {
-	    systrayMsg(__tr("Already checking for mail!"));
+	    systrayMsg(_i18n_("Already checking for mail!"));
 	    return;
 	}
 
@@ -506,13 +506,13 @@ void KviBiff::stopCheckingMail()
 {
 	if( ! m_pSocket )
 	{
-	    systrayMsg(__tr("Not checking mail right now!"));
+	    systrayMsg(_i18n_("Not checking mail right now!"));
 	    return;
 	}
 
 	delete m_pSocket;
 	m_pSocket = 0;
-	systrayMsg(__tr("Stopped checking mail."));
+	systrayMsg(_i18n_("Stopped checking mail."));
 	m_pCurrentIcon = g_iconNormal;
 }
 
@@ -539,7 +539,7 @@ bool biff_plugin_command_biff(KviPluginCommandStruct *cmd)
 	        KviSysTrayWidget *w = kvirc_plugin_lookup_systray_widget(cmd->frame, "KviBiffSysTray");
 	        if( !w ) {
 	            cmd->error    = KVI_ERROR_InvalidParameter;
-	            cmd->errorstr = __tr("No biff widget to undock");
+	            cmd->errorstr = _i18n_("No biff widget to undock");
 	            return false;
 	        }
 	        kvirc_plugin_remove_systray_widget(cmd->frame, w, true);
@@ -550,11 +550,11 @@ bool biff_plugin_command_biff(KviPluginCommandStruct *cmd)
 	KviSysTrayWidget *w = kvirc_plugin_lookup_systray_widget(cmd->frame, "KviBiffSysTray");
 	if( w ) {
 	    cmd->error    = KVI_ERROR_InvalidParameter;
-	    cmd->errorstr = __tr("Biff widget already docked in this frame");
+	    cmd->errorstr = _i18n_("Biff widget already docked in this frame");
 	    return false;
 	}
 
-	KviBiffSysTray *biff = new KviBiffSysTray(kvirc_plugin_get_systray(cmd->frame ), cmd->frame, __tr("Biff"));
+	KviBiffSysTray *biff = new KviBiffSysTray(kvirc_plugin_get_systray(cmd->frame ), cmd->frame, _i18n_("Biff"));
 	kvirc_plugin_add_systray_widget(cmd->handle, cmd->frame, biff, true);
 
 	return true;
