@@ -292,8 +292,8 @@ void KviStatController::slotRemoveAllChans()
 	if( m_pStatChanList->isEmpty() ) return;
 
 	if( KviMessageBox::warningYesNo(
-		_CHAR_2_QSTRING(__tr("Are you sure you want to remove all channels from your statistics?")),
-		_CHAR_2_QSTRING(__tr("Remove all channels"))) == KviMessageBox::Yes
+		_CHAR_2_QSTRING(_i18n_("Are you sure you want to remove all channels from your statistics?")),
+		_CHAR_2_QSTRING(_i18n_("Remove all channels"))) == KviMessageBox::Yes
 	) {
 		m_pStatChanList->clear();
 		g_pStatPluginStatWindow->updateStats();
@@ -360,8 +360,8 @@ bool KviStatController::showTopics() const                       { return m_conf
 bool KviStatController::doReset()
 {
 	if( KviMessageBox::warningYesNo(
-		_CHAR_2_QSTRING(__tr("Are you sure you want to reset your statistics?")),
-		_CHAR_2_QSTRING(__tr("Reset stats"))) == KviMessageBox::No
+		_CHAR_2_QSTRING(_i18n_("Are you sure you want to reset your statistics?")),
+		_CHAR_2_QSTRING(_i18n_("Reset stats"))) == KviMessageBox::No
 	) {
 		return false;
 	}
