@@ -25,6 +25,7 @@
 
 #include <dlfcn.h>
 
+#include <qdir.h>
 #include <qpainter.h>
 #include <qpixmap.h>
 
@@ -35,7 +36,6 @@
 #include "kvi_xmms.h"
 #include "kvi_xmms_icons.h"
 #include "kvi_xmms_widget.h"
-#include "kvirc_plugin.h"
 
 int   (*libxmms_remote_play)(int)                    = 0;
 int   (*libxmms_remote_stop)(int)                    = 0;
@@ -204,121 +204,136 @@ bool xmms_plugin_function_xmmsPlaylistTime(KviPluginCommandStruct *cmd, KviStr *
 
 bool xmms_plugin_init(KviPluginCommandStruct *cmd)
 {
-	libxmms_handle = dlopen("libxmms.so", RTLD_GLOBAL | RTLD_NOW);
+	// Find an appropriate XMMS lib
+	QDir libdir("/usr/lib");
+	libdir.setFilter(QDir::Files | QDir::NoSymLinks);
+	const QFileInfoList *list = libdir.entryInfoList("libxmms.so*");
+	QFileInfoListIterator iter(*list);
+	for( QFileInfo *fi = 0; (fi = iter.current()) != 0; ++iter ) {
+		if( xmms_plugin_load(cmd, fi->fileName() ) )
+			return true;
+	}
+	// Fallback measure
+	return xmms_plugin_load(cmd, "libxmms.so.1");
+}
+
+bool xmms_plugin_load(KviPluginCommandStruct *cmd, const QString filename)
+{
+	libxmms_handle = dlopen(filename.latin1(), RTLD_GLOBAL | RTLD_NOW);
 	if( !libxmms_handle ) {
-		debug("[libkvixmms]: could not load libxmms: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not load libxmms: %s", dlerror());
+		debug("[libkvixmms]: could not load %s: %s", filename.latin1(), dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: could not load %s: %s", (const char *) filename.utf8(), dlerror());
 		return false;
 	}
 	libxmms_remote_play = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_play");
 	if( !libxmms_remote_play ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_play: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_play: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_stop = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_stop");
 	if( !libxmms_remote_stop ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_stop: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_stop: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_playlist_prev = (void (*)(int)) dlsym(libxmms_handle, "xmms_remote_playlist_prev");
 	if( !libxmms_remote_playlist_prev ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_playlist_prev: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_playlist_prev: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_playlist_next = (void (*)(int)) dlsym(libxmms_handle, "xmms_remote_playlist_next");
 	if( !libxmms_remote_playlist_next ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_playlist_next: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_playlist_next: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_pause = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_pause");
 	if( !libxmms_remote_pause ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_pause: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_pause: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_eject = (void (*)(int)) dlsym(libxmms_handle, "xmms_remote_eject");
 	if( !libxmms_remote_eject ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_eject: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_eject: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_is_playing = (bool (*)(int)) dlsym(libxmms_handle, "xmms_remote_is_playing");
 	if( !libxmms_remote_is_playing ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_playing: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_playing: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_is_paused = (bool (*)(int)) dlsym(libxmms_handle, "xmms_remote_is_paused");
 	if( !libxmms_remote_is_paused ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_is_paused: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_is_paused: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_is_running = (bool (*)(int)) dlsym(libxmms_handle, "xmms_remote_is_running");
 	if( !libxmms_remote_is_running ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_is_running: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_is_running: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_playlist_file = (char * (*)(int, int)) dlsym(libxmms_handle, "xmms_remote_get_playlist_file");
 	if( !libxmms_remote_get_playlist_file ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_playlist_file: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_playlist_file: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_playlist_time = (int (*)(int, int)) dlsym(libxmms_handle, "xmms_remote_get_playlist_time");
 	if( !libxmms_remote_get_playlist_time ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_playlist_time: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_playlist_time: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_playlist_title = (char * (*)(int, int)) dlsym(libxmms_handle, "xmms_remote_get_playlist_title");
 	if( !libxmms_remote_get_playlist_title ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_playlist_title: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_playlist_title: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_playlist_pos = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_get_playlist_pos");
 	if( !libxmms_remote_get_playlist_pos ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_playlist_pos: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_playlist_pos: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_playlist_length = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_get_playlist_length");
 	if( !libxmms_remote_get_playlist_length ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_playlist_length: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_playlist_length: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_get_main_volume = (int (*)(int)) dlsym(libxmms_handle, "xmms_remote_get_main_volume");
 	if( !libxmms_remote_get_main_volume ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_get_main_volume: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_get_main_volume: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
 	libxmms_remote_set_main_volume = (void (*)(int, int)) dlsym(libxmms_handle, "xmms_remote_set_main_volume");
 	if( !libxmms_remote_set_main_volume ) {
-		debug("[libkvixmms]: could not find symbol xmms_remote_set_main_volume: %s", dlerror());
-		cmd->errorstr.sprintf("[libkvixmms]: could not find symbol xmms_remote_set_main_volume: %s", dlerror());
+		debug("[libkvixmms]: %s", dlerror());
+		cmd->errorstr.sprintf("[libkvixmms]: %s", dlerror());
 		dlclose(libxmms_handle);
 		return false;
 	}
